@@ -228,7 +228,7 @@ open_keyadder (LPVOID arg)
   if (err)
     {
       log_error ("%s:%s: Err code: %i asString: %s",
-                 SRCNAME, __func__, err.code(), err.asString());
+                 SRCNAME, __func__, err.code(), err.asStdString().c_str());
       TRETURN 0;
     }
 
